@@ -28,7 +28,16 @@ public_api = [
 
 def select_backend(name):
     """Select the pyzmq backend"""
-    mod = __import__(name, fromlist=public_api)
+    try:
+        mod = __import__(name, fromlist=public_api)
+    except ImportError:
+        raise
+    except Exception as e:
+        import sys
+        from zmq.utils.sixcerpt import reraise
+        exc_info = sys.exc_info()
+        reraise(ImportError, ImportError("Importing %s failed with %s" % (name, e)), exc_info[2])
+    
     ns = {}
     for key in public_api:
         ns[key] = getattr(mod, key)
